cmoncrawl.processor.pipeline.extractor.BaseExtractor.extract
============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: BaseExtractor.extract